==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCMedal/studyCard/index.js <==
import React from 'react'
import css from "../index.scss";
import ShowView from '../showView/index'
import ShowViewN from '../showViewN/index'
import { Tabs } from 'antd';
const { TabPane } = Tabs;

export default class StudyCard extends React.Component{

    state={
        fadIn:false,//展开与隐藏
        visible:false,//消失隐藏弹框
        list:{},
    }
    handleClick=()=>{
        this.setState({
            fadIn:!this.state.fadIn
        })
    }
    medalshow=(madal)=>{
        this.setState({visible:true,list:madal})
    }
    callback=(res)=>{
        this.setState({visible:res})
    }
   
    render(){
        const {fadIn,visible,list,year} = this.state
        const {card=[],Modal,ConfigStore:{config:{httpAgent}},isStudy,arrYear=[]} = this.props

        const replaceStyle = {
            backgroundColor:'rgba(0,0,0,.1)'
        }
        return(
            <div className={css.cards}>
                  <div className={`${css.title} ${css.clearfix}`}>
                  <div className={css.left}>
                      <div className={css.hr}></div>
                      <div className={css.img}>
                          <img src={card[0]&&card[0].iconUrl} alt={'img'}/>
                      </div>
                      <span>{card[0]&&card[0].categoryName}</span>
                  </div>
                 </div>
              
              
                <div className={`${css.contont} ${css.clearfix}`}>  
                    <Tabs type="card" onChange={(year)=>this.setState({year})}>
                        {arrYear.map((v,i) => (
                            
                            <TabPane tab={v} key={v}>
                            <div className={css.right}>
                                <div className={css.text}><em>{card[i].mineMedalCount}</em>/{card[i].medalResults.length}</div>
                                {card[i].medalResults.length>7&&<div onClick={this.handleClick}
                                                                className={`${css.btn} ${'kuc-iconfont'}
                                    ${fadIn?'kuc-small-arrow-top-copy':'kuc-small-arrow-bottom-copy'}`}>
                                </div>}

                            </div>
                                
                           {     
                               card&&card[i].medalResults.map((o,j)=>{
                                if(!fadIn&&j<7){
                                    return (
                                        <div className={css.icons} key={j} onClick={()=>this.medalshow(o)}
                                            style={{filter:`${o.won?'':'grayscale(100%)'}`}} >
                                            <div><img src={o.medalIcon} alt={'img'}/></div>
                                            <span>{o.medalName}</span>
                                        </div>
                                    )
                                }
                                else if(fadIn){
                                    return (
                                        <div className={css.icons} key={j} onClick={()=>this.medalshow(o)}
                                            style={{filter:`${o.won?'':'grayscale(100%)'}`}}>
                                            <div><img src={o.medalIcon} alt={'img'}/></div>
                                            <span>{o.medalName}</span>
                                        </div>
                                    )
                                }
                            }
                        )}
                            </TabPane>
                        ))}
                    </Tabs>
                </div>
                <Modal {...{show:visible,replaceStyle}}>
                    {list&&list.won?<ShowView list={list} {...this.props} callback={(res)=>this.callback(res)} year={year}/>
                        :<ShowViewN list={list} {...this.props} callback={(res)=>this.callback(res)}/>}
                </Modal>
            </div>
        )
    }
}

==> kara-uc-1.2.30.tgz: package/src/kara-uc/components/UCMedal/studyCard/index.js <==
import React from 'react'
import css from "../index.scss";
import ShowView from '../showView/index'
import ShowViewN from '../showViewN/index'
import { Tabs } from 'antd';
const { TabPane } = Tabs;

export default class StudyCard extends React.Component{

    state={
        fadIn:false,//展开与隐藏
        visible:false,//消失隐藏弹框
        list:{},
    }
    handleClick=()=>{
        this.setState({
            fadIn:!this.state.fadIn
        })
    }
    medalshow=(madal)=>{
        this.setState({visible:true,list:madal})
    }
    callback=(res)=>{
        this.setState({visible:res})
    }
   
    render(){
        const {fadIn,visible,list,year} = this.state
        const {card=[],Modal,ConfigStore:{config:{httpAgent}},isStudy,arrYear=[]} = this.props

        const replaceStyle = {
            backgroundColor:'rgba(0,0,0,.1)'
        }
        return(
            <div className={css.cards}>
                  <div className={`${css.title} ${css.clearfix}`}>
                  <div className={css.left}>
                      <div className={css.hr}></div>
                      <div className={css.img}>
                          <img src={card[0]&&card[0].iconUrl} alt={'img'}/>
                      </div>
                      <span>{card[0]&&card[0].categoryName}</span>
                  </div>
                 </div>
              
              
                <div className={`${css.contont} ${css.clearfix}`}>  
                    <Tabs type="card" onChange={(year)=>this.setState({year})}>
                        {arrYear.map((v,i) => (
                            
                            <TabPane tab={v} key={v}>
                            <div className={css.right}>
                                <div className={css.text}><em>{card[i].mineMedalCount}</em>/{card[i].medalResults.length}</div>
                                {card[i].medalResults.length>7&&<div onClick={this.handleClick}
                                                                className={`${css.btn} ${'kuc-iconfont'}
                                    ${fadIn?'kuc-small-arrow-top-copy':'kuc-small-arrow-bottom-copy'}`}>
                                </div>}

                            </div>
                                
                           {     
                               card&&card[i].medalResults.map((o,j)=>{
                                if(!fadIn&&j<7){
                                    return (
                                        <div className={css.icons} key={j} onClick={()=>this.medalshow(o)}
                                            style={{filter:`${o.won?'':'grayscale(100%)'}`}} >
                                            <div><img src={o.medalIcon} alt={'img'}/></div>
                                            <span>{o.medalName}</span>
                                        </div>
                                    )
                                }
                                else if(fadIn){
                                    return (
                                        <div className={css.icons} key={j} onClick={()=>this.medalshow(o)}
                                            style={{filter:`${o.won?'':'grayscale(100%)'}`}}>
                                            <div><img src={o.medalIcon} alt={'img'}/></div>
                                            <span>{o.medalName}</span>
                                        </div>
                                    )
                                }
                            }
                        )}
                            </TabPane>
                        ))}
                    </Tabs>
                </div>
                <Modal {...{show:visible,replaceStyle}}>
                    {list&&list.won?<ShowView list={list} {...this.props} callback={(res)=>this.callback(res)} year={year}/>
                        :<ShowViewN list={list} {...this.props} callback={(res)=>this.callback(res)} year={year}/>}
                </Modal>
            </div>
        )
    }
}
